==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.md <==
# AwsBackupRecoveryPointObjective


```text
aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective
```

```text
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')
```



| Illustration | AwsBackupRecoveryPointObjective | AwsBackupRecoveryPointObjectiveCard | AwsBackupRecoveryPointObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.png) | ![illustration for AwsBackupRecoveryPointObjective](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveCard](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveGroup](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjectiveGroup.Local.png) |




## AwsBackupRecoveryPointObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

## AwsBackupRecoveryPointObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryPointObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.md <==
# AwsBackupRecoveryPointObjective


```text
aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective
```

```text
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')
```



| Illustration | AwsBackupRecoveryPointObjective | AwsBackupRecoveryPointObjectiveCard | AwsBackupRecoveryPointObjectiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.png) | ![illustration for AwsBackupRecoveryPointObjective](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveCard](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjectiveCard.Local.png) | ![illustration for AwsBackupRecoveryPointObjectiveGroup](../../../aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjectiveGroup.Local.png) |




## AwsBackupRecoveryPointObjective

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjective
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjective('AwsBackupRecoveryPointObjective', 'Aws Backup Recovery Point Objective', 'an optional tech label')
@enduml
```

## AwsBackupRecoveryPointObjectiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveCard
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveCard('AwsBackupRecoveryPointObjectiveCard', 'Aws Backup Recovery Point Objective Card', 'an optional description')
@enduml
```

## AwsBackupRecoveryPointObjectiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsBackupRecoveryPointObjectiveGroup
include('aws-20210730/Resource/Storage/AwsBackupRecoveryPointObjective')

' renders the element
AwsBackupRecoveryPointObjectiveGroup('AwsBackupRecoveryPointObjectiveGroup', 'Aws Backup Recovery Point Objective Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
